@@ -3,8 +3,6 @@ __license__ = "Apache-2.0"
 
 import argparse
 
-from ..helper import colored
-
 
 def add_arg_group(parser, title):
     return parser.add_argument_group(title)
@@ -220,7 +218,7 @@ def set_pea_parser(parser=None):
                           'set this to -1 to disable this feature.')
     gp5.add_argument('--compress-lwm', type=float, default=1.,
                      help='the low watermark that enables the sending of a compressed message. '
-                          'compression rate (after_size/before_size) lower than this LWM will considered as successeful '
+                          'compression rate (after_size/before_size) lower than this LWM will be considered as successeful '
                           'compression, and will be sent. Otherwise, it will send the original message without compression')
     gp5.add_argument('--num-part', type=int, default=1,
                      help='wait until the number of parts of message are all received')
@@ -511,6 +509,7 @@ class _ColoredHelpFormatter(argparse.ArgumentDefaultsHelpFormatter):
 
             # add the heading if the section was non-empty
             if self.heading is not argparse.SUPPRESS and self.heading is not None:
+                from ..helper import colored
                 current_indent = self.formatter._current_indent
                 captial_heading = ' '.join(v[0].upper() + v[1:] for v in self.heading.split(' '))
                 heading = '⚙️  %*s%s\n' % (
@@ -531,6 +530,7 @@ class _ColoredHelpFormatter(argparse.ArgumentDefaultsHelpFormatter):
         help = action.help
         if '%(default)' not in action.help:
             if action.default is not argparse.SUPPRESS:
+                from ..helper import colored
                 defaulting_nargs = [argparse.OPTIONAL, argparse.ZERO_OR_MORE]
                 if isinstance(action, argparse._StoreTrueAction):
 
